pub struct CommandResultEvent<T>{
pub result: T,
pub executor: Entity,
pub modifiers: HashMap<ModifierValue, ModifierValue>,
}Fields
result: Texecutor: Entitymodifiers: HashMap<ModifierValue, ModifierValue>Trait Implementations
Sourceimpl<T> Component for CommandResultEvent<T>
impl<T> Component for CommandResultEvent<T>
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::SparseSet
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::SparseSet
A constant indicating the storage type used for this component.
fn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its [
ComponentHooks].impl<T> Event for CommandResultEvent<T>